@@ -14,6 +14,11 @@ import aws_cdk.aws_s3
 import aws_cdk.aws_s3_deployment
 import aws_cdk.core
 import aws_cdk.custom_resources
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("aws-cdk-dynamodb-seeder", "1.36.0", __name__[0:-6], "aws-cdk-dynamodb-seeder@1.36.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
